@@ -2,21 +2,22 @@
 
 """Series-related objects."""
 
-from __future__ import absolute_import, print_function, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from collections import Sequence
-
-from ..dml.chtfmt import ChartFormat
-from .marker import Marker
-from ..oxml.ns import qn
-from .point import BubblePoints, CategoryPoints, XyPoints
-from ..util import lazyproperty
+from pptx.chart.datalabel import DataLabels
+from pptx.chart.marker import Marker
+from pptx.chart.point import BubblePoints, CategoryPoints, XyPoints
+from pptx.compat import Sequence
+from pptx.dml.chtfmt import ChartFormat
+from pptx.oxml.ns import qn
+from pptx.util import lazyproperty
 
 
 class _BaseSeries(object):
     """
     Base class for |BarSeries| and other series classes.
     """
+
     def __init__(self, ser):
         super(_BaseSeries, self).__init__()
         self._element = ser
@@ -45,15 +46,19 @@ class _BaseSeries(object):
         column for this series in the Excel worksheet. It also appears as the
         label for this series in the legend.
         """
-        names = self._element.xpath('./c:tx//c:pt/c:v/text()')
-        name = names[0] if names else ''
+        names = self._element.xpath("./c:tx//c:pt/c:v/text()")
+        name = names[0] if names else ""
         return name
 
 
 class _BaseCategorySeries(_BaseSeries):
-    """
-    Base class for |BarSeries| and other category chart series classes.
-    """
+    """Base class for |BarSeries| and other category chart series classes."""
+
+    @lazyproperty
+    def data_labels(self):
+        """|DataLabels| object controlling data labels for this series."""
+        return DataLabels(self._ser.get_or_add_dLbls())
+
     @lazyproperty
     def points(self):
         """
@@ -68,6 +73,7 @@ class _BaseCategorySeries(_BaseSeries):
         Read-only. A sequence containing the float values for this series, in
         the order they appear on the chart.
         """
+
         def iter_values():
             val = self._element.val
             if val is None:
@@ -83,6 +89,7 @@ class _MarkerMixin(object):
     Mixin class providing `.marker` property for line-type chart series. The
     line-type charts are Line, XY, and Radar.
     """
+
     @lazyproperty
     def marker(self):
         """
@@ -129,6 +136,7 @@ class LineSeries(_BaseCategorySeries, _MarkerMixin):
     """
     A data point series belonging to a line plot.
     """
+
     @property
     def smooth(self):
         """
@@ -163,6 +171,7 @@ class XySeries(_BaseSeries, _MarkerMixin):
     """
     A data point series belonging to an XY (scatter) plot.
     """
+
     def iter_values(self):
         """
         Generate each float Y value in this series, in the order they appear
@@ -197,6 +206,7 @@ class BubbleSeries(XySeries):
     """
     A data point series belonging to a bubble plot.
     """
+
     @lazyproperty
     def points(self):
         """
@@ -211,6 +221,7 @@ class SeriesCollection(Sequence):
     """
     A sequence of |Series| objects.
     """
+
     def __init__(self, parent_elm):
         # *parent_elm* can be either a c:plotArea or xChart element
         super(SeriesCollection, self).__init__()
@@ -233,18 +244,18 @@ def _SeriesFactory(ser):
 
     try:
         SeriesCls = {
-            qn('c:areaChart'):     AreaSeries,
-            qn('c:barChart'):      BarSeries,
-            qn('c:bubbleChart'):   BubbleSeries,
-            qn('c:doughnutChart'): PieSeries,
-            qn('c:lineChart'):     LineSeries,
-            qn('c:pieChart'):      PieSeries,
-            qn('c:radarChart'):    RadarSeries,
-            qn('c:scatterChart'):  XySeries,
+            qn("c:areaChart"): AreaSeries,
+            qn("c:barChart"): BarSeries,
+            qn("c:bubbleChart"): BubbleSeries,
+            qn("c:doughnutChart"): PieSeries,
+            qn("c:lineChart"): LineSeries,
+            qn("c:pieChart"): PieSeries,
+            qn("c:radarChart"): RadarSeries,
+            qn("c:scatterChart"): XySeries,
         }[xChart_tag]
     except KeyError:
         raise NotImplementedError(
-            'series class for %s not yet implemented' % xChart_tag
+            "series class for %s not yet implemented" % xChart_tag
         )
 
     return SeriesCls(ser)
