@@ -2,29 +2,31 @@
 
 """MediaPart and related objects."""
 
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import hashlib
 
-from ..opc.package import Part
-from ..util import lazyproperty
+from pptx.opc.package import Part
+from pptx.util import lazyproperty
 
 
 class MediaPart(Part):
     """A media part, containing an audio or video resource.
 
     A media part generally has a partname matching the regex
-    ``ppt/media/media[1-9][0-9]*.*``.
+    `ppt/media/media[1-9][0-9]*.*`.
     """
 
     @classmethod
     def new(cls, package, media):
-        """Return new |MediaPart| instance containing *media*.
+        """Return new |MediaPart| instance containing `media`.
 
-        *media* must be a |Media| object.
+        `media` must be a |Media| object.
         """
-        partname = package.next_media_partname(media.ext)
-        return cls(partname, media.content_type, media.blob, package)
+        return cls(
+            package.next_media_partname(media.ext),
+            media.content_type,
+            package,
+            media.blob,
+        )
 
     @lazyproperty
     def sha1(self):
