@@ -1,23 +1,19 @@
 # encoding: utf-8
 
-"""
-Presentation part, the main part in a .pptx package.
-"""
+"""Presentation part, the main part in a .pptx package."""
 
-from __future__ import absolute_import
-
-from ..opc.constants import RELATIONSHIP_TYPE as RT
-from ..opc.package import XmlPart
-from ..opc.packuri import PackURI
-from ..presentation import Presentation
-from .slide import NotesMasterPart, SlidePart
-from ..util import lazyproperty
+from pptx.opc.constants import RELATIONSHIP_TYPE as RT
+from pptx.opc.package import XmlPart
+from pptx.opc.packuri import PackURI
+from pptx.parts.slide import NotesMasterPart, SlidePart
+from pptx.presentation import Presentation
+from pptx.util import lazyproperty
 
 
 class PresentationPart(XmlPart):
-    """
-    Top level class in object model, represents the contents of the /ppt
-    directory of a .pptx file.
+    """Top level class in object model.
+
+    Represents the contents of the /ppt directory of a .pptx file.
     """
 
     def add_slide(self, slide_layout):
@@ -40,13 +36,13 @@ class PresentationPart(XmlPart):
         return self.package.core_properties
 
     def get_slide(self, slide_id):
-        """
-        Return the |Slide| object identified by *slide_id* (in this
-        presentation), or |None| if not found.
+        """Return optional related |Slide| object identified by `slide_id`.
+
+        Returns |None| if no slide with `slide_id` is related to this presentation.
         """
         for sldId in self._element.sldIdLst:
             if sldId.id == slide_id:
-                return self.related_parts[sldId.rId].slide
+                return self.related_part(sldId.rId).slide
         return None
 
     @lazyproperty
@@ -83,56 +79,43 @@ class PresentationPart(XmlPart):
         return Presentation(self._element, self)
 
     def related_slide(self, rId):
-        """
-        Return the |Slide| object for the related |SlidePart| corresponding
-        to relationship key *rId*.
-        """
-        return self.related_parts[rId].slide
+        """Return |Slide| object for related |SlidePart| related by `rId`."""
+        return self.related_part(rId).slide
 
     def related_slide_master(self, rId):
-        """
-        Return the |SlideMaster| object for the related |SlideMasterPart|
-        corresponding to relationship key *rId*.
-        """
-        return self.related_parts[rId].slide_master
+        """Return |SlideMaster| object for |SlideMasterPart| related by `rId`."""
+        return self.related_part(rId).slide_master
 
     def rename_slide_parts(self, rIds):
-        """
-        Assign incrementing partnames like ``/ppt/slides/slide9.xml`` to the
-        slide parts identified by *rIds*, in the order their id appears in
-        that sequence. The name portion is always ``slide``. The number part
-        forms a continuous sequence starting at 1 (e.g. 1, 2, ... 10, ...).
+        """Assign incrementing partnames to the slide parts identified by `rIds`.
+
+        Partnames are like `/ppt/slides/slide9.xml` and are assigned in the order their
+        id appears in the `rIds` sequence. The name portion is always ``slide``. The
+        number part forms a continuous sequence starting at 1 (e.g. 1, 2, ... 10, ...).
         The extension is always ``.xml``.
         """
         for idx, rId in enumerate(rIds):
-            slide_part = self.related_parts[rId]
+            slide_part = self.related_part(rId)
             slide_part.partname = PackURI("/ppt/slides/slide%d.xml" % (idx + 1))
 
     def save(self, path_or_stream):
-        """
-        Save this presentation package to *path_or_stream*, which can be
-        either a path to a filesystem location (a string) or a file-like
-        object.
+        """Save this presentation package to `path_or_stream`.
+
+        `path_or_stream` can be either a path to a filesystem location (a string) or a
+        file-like object.
         """
         self.package.save(path_or_stream)
 
     def slide_id(self, slide_part):
-        """
-        Return the slide identifier associated with *slide_part* in this
-        presentation.
-        """
+        """Return the slide-id associated with `slide_part`."""
         for sldId in self._element.sldIdLst:
-            if self.related_parts[sldId.rId] is slide_part:
+            if self.related_part(sldId.rId) is slide_part:
                 return sldId.id
         raise ValueError("matching slide_part not found")
 
     @property
     def _next_slide_partname(self):
-        """
-        Return |PackURI| instance containing the partname for a slide to be
-        appended to this slide collection, e.g. ``/ppt/slides/slide9.xml``
-        for a slide collection containing 8 slides.
-        """
+        """Return |PackURI| instance containing next available slide partname."""
         sldIdLst = self._element.get_or_add_sldIdLst()
         partname_str = "/ppt/slides/slide%d.xml" % (len(sldIdLst) + 1)
         return PackURI(partname_str)
