@@ -2,10 +2,10 @@
 
 """The shape tree, the structure that holds a slide's shapes."""
 
-from __future__ import absolute_import, division, print_function, unicode_literals
+import os
 
 from pptx.compat import BytesIO
-from pptx.enum.shapes import PP_PLACEHOLDER
+from pptx.enum.shapes import PP_PLACEHOLDER, PROG_ID
 from pptx.media import SPEAKER_IMAGE_BYTES, Video
 from pptx.opc.constants import CONTENT_TYPE as CT
 from pptx.oxml.ns import qn
@@ -31,7 +31,7 @@ from pptx.shapes.placeholder import (
     TablePlaceholder,
 )
 from pptx.shared import ParentedElementProxy
-from pptx.util import lazyproperty
+from pptx.util import Emu, lazyproperty
 
 # +-- _BaseShapes
 # |   |
@@ -97,9 +97,7 @@ class _BaseShapes(ParentedElementProxy):
         return len(shape_elms)
 
     def clone_placeholder(self, placeholder):
-        """
-        Add a new placeholder shape based on *placeholder*.
-        """
+        """Add a new placeholder shape based on *placeholder*."""
         sp = placeholder.element
         ph_type, orient, sz, idx = (sp.ph_type, sp.ph_orient, sp.ph_sz, sp.ph_idx)
         id_ = self._next_shape_id
@@ -280,6 +278,46 @@ class _BaseGroupShapes(_BaseShapes):
             grpSp.recalculate_extents()
         return self._shape_factory(grpSp)
 
+    def add_ole_object(
+        self, object_file, prog_id, left, top, width=None, height=None, icon_file=None
+    ):
+        """Return newly-created GraphicFrame shape embedding `object_file`.
+
+        The returned graphic-frame shape contains `object_file` as an embedded OLE
+        object. It is displayed as an icon at `left`, `top` with size `width`, `height`.
+        `width` and `height` may be omitted when `prog_id` is a member of `PROG_ID`, in
+        which case the default icon size is used. This is advised for best appearance
+        where applicable because it avoids an icon with a "stretched" appearance.
+
+        `object_file` may either be a str path to the file or a file-like
+        object (such as `io.BytesIO`) containing the bytes of the object file.
+
+        `prog_id` can be either a member of `pptx.enum.shapes.PROG_ID` or a str value
+        like `"Adobe.Exchange.7"` determined by inspecting the XML generated by
+        PowerPoint for an object of the desired type.
+
+        `icon_file` may either be a str path to an image file or a file-like object
+        containing the image. The image provided will be displayed in lieu of the OLE
+        object; double-clicking on the image opens the object (subject to
+        operating-system limitations). The image file can be any supported image file.
+        Those produced by PowerPoint itself are generally EMF and can be harvested from
+        a PPTX package that embeds such an object. PNG and JPG also work fine.
+        """
+        graphicFrame = _OleObjectElementCreator.graphicFrame(
+            self,
+            self._next_shape_id,
+            object_file,
+            prog_id,
+            left,
+            top,
+            width,
+            height,
+            icon_file,
+        )
+        self._spTree.append(graphicFrame)
+        self._recalculate_extents()
+        return self._shape_factory(graphicFrame)
+
     def add_picture(self, image_file, left, top, width=None, height=None):
         """Add picture shape displaying image in *image_file*.
 
@@ -715,8 +753,6 @@ class SlidePlaceholders(ParentedElementProxy):
     placeholders it contains.
     """
 
-    __slots__ = ()
-
     def __getitem__(self, idx):
         """
         Access placeholder shape having *idx*. Note that while this looks
@@ -951,3 +987,145 @@ class _MoviePicElementCreator(object):
         one is the video rId and the other is the media rId.
         """
         return self._video_part_rIds[1]
+
+
+class _OleObjectElementCreator(object):
+    """Functional service object for creating a new OLE-object p:graphicFrame element.
+
+    It's entire external interface is its :meth:`graphicFrame` class method that returns
+    a new `p:graphicFrame` element containing the specified embedded OLE-object shape.
+    This class is not intended to be constructed or an instance of it retained by the
+    caller; it is a "one-shot" object, really a function wrapped in a object such that
+    its helper methods can be organized here.
+    """
+
+    def __init__(
+        self, shapes, shape_id, ole_object_file, prog_id, x, y, cx, cy, icon_file
+    ):
+        self._shapes = shapes
+        self._shape_id = shape_id
+        self._ole_object_file = ole_object_file
+        self._prog_id_arg = prog_id
+        self._x = x
+        self._y = y
+        self._cx_arg = cx
+        self._cy_arg = cy
+        self._icon_file_arg = icon_file
+
+    @classmethod
+    def graphicFrame(
+        cls, shapes, shape_id, ole_object_file, prog_id, x, y, cx, cy, icon_file
+    ):
+        """Return new `p:graphicFrame` element containing embedded `ole_object_file`."""
+        return cls(
+            shapes, shape_id, ole_object_file, prog_id, x, y, cx, cy, icon_file
+        )._graphicFrame
+
+    @lazyproperty
+    def _graphicFrame(self):
+        """Newly-created `p:graphicFrame` element referencing embedded OLE-object."""
+        return CT_GraphicalObjectFrame.new_ole_object_graphicFrame(
+            self._shape_id,
+            self._shape_name,
+            self._ole_object_rId,
+            self._progId,
+            self._icon_rId,
+            self._x,
+            self._y,
+            self._cx,
+            self._cy,
+        )
+
+    @lazyproperty
+    def _cx(self):
+        """Emu object specifying width of "show-as-icon" image for OLE shape."""
+        # --- a user-specified width overrides any default ---
+        if self._cx_arg is not None:
+            return self._cx_arg
+
+        # --- the default width is specified by the PROG_ID member if prog_id is one,
+        # --- otherwise it gets the default icon width.
+        return (
+            Emu(self._prog_id_arg.width)
+            if self._prog_id_arg in PROG_ID
+            else Emu(965200)
+        )
+
+    @lazyproperty
+    def _cy(self):
+        """Emu object specifying height of "show-as-icon" image for OLE shape."""
+        # --- a user-specified width overrides any default ---
+        if self._cy_arg is not None:
+            return self._cy_arg
+
+        # --- the default height is specified by the PROG_ID member if prog_id is one,
+        # --- otherwise it gets the default icon height.
+        return (
+            Emu(self._prog_id_arg.height)
+            if self._prog_id_arg in PROG_ID
+            else Emu(609600)
+        )
+
+    @lazyproperty
+    def _icon_image_file(self):
+        """Reference to image file containing icon to show in lieu of this object.
+
+        This can be either a str path or a file-like object (io.BytesIO typically).
+        """
+        # --- a user-specified icon overrides any default ---
+        if self._icon_file_arg is not None:
+            return self._icon_file_arg
+
+        # --- A prog_id belonging to PROG_ID gets its icon filename from there. A
+        # --- user-specified (str) prog_id gets the default icon.
+        icon_filename = (
+            self._prog_id_arg.icon_filename
+            if self._prog_id_arg in PROG_ID
+            else "generic-icon.emf"
+        )
+
+        _thisdir = os.path.split(__file__)[0]
+        return os.path.abspath(os.path.join(_thisdir, "..", "templates", icon_filename))
+
+    @lazyproperty
+    def _icon_rId(self):
+        """str rId like "rId7" of rel to icon (image) representing OLE-object part."""
+        _, rId = self._slide_part.get_or_add_image_part(self._icon_image_file)
+        return rId
+
+    @lazyproperty
+    def _ole_object_rId(self):
+        """str rId like "rId6" of relationship to embedded ole_object part.
+
+        This is where the ole_object part and its relationship to the slide are actually
+        created.
+        """
+        return self._slide_part.add_embedded_ole_object_part(
+            self._prog_id_arg, self._ole_object_file
+        )
+
+    @lazyproperty
+    def _progId(self):
+        """str like "Excel.Sheet.12" identifying program used to open object.
+
+        This value appears in the `progId` attribute of the `p:oleObj` element for the
+        object.
+        """
+        prog_id_arg = self._prog_id_arg
+
+        # --- member of PROG_ID enumeration knows its progId keyphrase, otherwise caller
+        # --- has specified it explicitly (as str)
+        return prog_id_arg.progId if prog_id_arg in PROG_ID else prog_id_arg
+
+    @lazyproperty
+    def _shape_name(self):
+        """str name like "Object 1" for the embedded ole_object shape.
+
+        The name is formed from the prefix "Object " and the shape-id decremented by 1.
+        """
+        return "Object %d" % (self._shape_id - 1)
+
+    @lazyproperty
+    def _slide_part(self):
+        """SlidePart object for this slide."""
+        return self._shapes.part
