@@ -1,10 +1,6 @@
 # encoding: utf-8
 
-"""
-Test suite for pptx.package module
-"""
-
-from __future__ import absolute_import, division, print_function, unicode_literals
+"""Unit-test suite for `pptx.package` module."""
 
 import pytest
 
@@ -22,6 +18,8 @@ from .unitutil.mock import call, class_mock, instance_mock, method_mock, propert
 
 
 class DescribePackage(object):
+    """Unit-test suite for `pptx.package.Package` objects."""
+
     def it_provides_access_to_its_core_properties_part(self):
         pkg = Package.open("pptx/templates/default.pptx")
         assert isinstance(pkg.core_properties, CorePropertiesPart)
@@ -58,7 +56,7 @@ class DescribePackage(object):
 
     @pytest.fixture
     def image_part_fixture(self, image_parts_, image_part_, _image_parts_prop_):
-        package = Package()
+        package = Package(None)
         image_file = "foobar.png"
         _image_parts_prop_.return_value = image_parts_
         image_parts_.get_or_add_image_part.return_value = image_part_
@@ -66,21 +64,21 @@ class DescribePackage(object):
 
     @pytest.fixture
     def media_part_fixture(self, media_, media_part_, _media_parts_prop_, media_parts_):
-        package = Package()
+        package = Package(None)
         _media_parts_prop_.return_value = media_parts_
         media_parts_.get_or_add_media_part.return_value = media_part_
         return package, media_, media_part_
 
     @pytest.fixture
     def m_parts_fixture(self, _MediaParts_, media_parts_):
-        package = Package()
+        package = Package(None)
         _MediaParts_.return_value = media_parts_
         return package, _MediaParts_, media_parts_
 
     @pytest.fixture(params=[((3, 4, 2), 1), ((4, 2, 1), 3), ((2, 3, 1), 4)])
     def next_fixture(self, request, iter_parts_):
         idxs, idx = request.param
-        package = Package()
+        package = Package(None)
         package.iter_parts.return_value = self.i_image_parts(request, idxs)
         ext = "foo"
         expected_value = "/ppt/media/image%d.%s" % (idx, ext)
@@ -89,7 +87,7 @@ class DescribePackage(object):
     @pytest.fixture(params=[((3, 4, 2), 1), ((4, 2, 1), 3), ((2, 3, 1), 4)])
     def nmp_fixture(self, request, iter_parts_):
         idxs, idx = request.param
-        package = Package()
+        package = Package(None)
         package.iter_parts.return_value = self.i_media_parts(request, idxs)
         ext = "foo"
         expected_value = "/ppt/media/media%d.%s" % (idx, ext)
@@ -149,27 +147,37 @@ class DescribePackage(object):
 
 
 class Describe_ImageParts(object):
+    """Unit-test suite for `pptx.package._ImageParts` objects."""
+
     def it_can_iterate_over_the_package_image_parts(self, iter_fixture):
         image_parts, expected_parts = iter_fixture
         assert list(image_parts) == expected_parts
 
-    def it_can_get_a_matching_image_part(self, get_fixture):
-        image_parts, image_file, Image_, image_, image_part_ = get_fixture
+    def it_can_get_a_matching_image_part(
+        self, Image_, image_, image_part_, _find_by_sha1_
+    ):
+        Image_.from_file.return_value = image_
+        _find_by_sha1_.return_value = image_part_
+        image_parts = _ImageParts(None)
 
-        image_part = image_parts.get_or_add_image_part(image_file)
+        image_part = image_parts.get_or_add_image_part("image.png")
 
-        Image_.from_file.assert_called_once_with(image_file)
-        image_parts._find_by_sha1.assert_called_once_with(image_.sha1)
+        Image_.from_file.assert_called_once_with("image.png")
+        _find_by_sha1_.assert_called_once_with(image_parts, image_.sha1)
         assert image_part is image_part_
 
-    def it_can_add_an_image_part(self, add_fixture):
-        image_parts, image_file, Image_, image_ = add_fixture[:4]
-        ImagePart_, package_, image_part_ = add_fixture[4:]
+    def it_can_add_an_image_part(
+        self, package_, Image_, image_, _find_by_sha1_, ImagePart_, image_part_
+    ):
+        Image_.from_file.return_value = image_
+        _find_by_sha1_.return_value = None
+        ImagePart_.new.return_value = image_part_
+        image_parts = _ImageParts(package_)
 
-        image_part = image_parts.get_or_add_image_part(image_file)
+        image_part = image_parts.get_or_add_image_part("image.png")
 
-        Image_.from_file.assert_called_once_with(image_file)
-        image_parts._find_by_sha1.assert_called_once_with(image_.sha1)
+        Image_.from_file.assert_called_once_with("image.png")
+        _find_by_sha1_.assert_called_once_with(image_parts, image_.sha1)
         ImagePart_.new.assert_called_once_with(package_, image_)
         assert image_part is image_part_
 
@@ -192,25 +200,6 @@ class Describe_ImageParts(object):
 
     # fixtures ---------------------------------------------
 
-    @pytest.fixture
-    def add_fixture(
-        self, package_, Image_, image_, _find_by_sha1_, ImagePart_, image_part_
-    ):
-        image_parts = _ImageParts(package_)
-        image_file = "foobar.png"
-        Image_.from_file.return_value = image_
-        _find_by_sha1_.return_value = None
-        ImagePart_.new.return_value = image_part_
-        return (
-            image_parts,
-            image_file,
-            Image_,
-            image_,
-            ImagePart_,
-            package_,
-            image_part_,
-        )
-
     @pytest.fixture(params=[True, False])
     def find_fixture(self, request, _iter_, image_part_):
         image_part_is_present = request.param
@@ -225,14 +214,6 @@ class Describe_ImageParts(object):
             expected_value = None
         return image_parts, sha1, expected_value
 
-    @pytest.fixture
-    def get_fixture(self, Image_, image_, image_part_, _find_by_sha1_):
-        image_parts = _ImageParts(None)
-        image_file = "foobar.png"
-        Image_.from_file.return_value = image_
-        _find_by_sha1_.return_value = image_part_
-        return image_parts, image_file, Image_, image_, image_part_
-
     @pytest.fixture
     def iter_fixture(self, request, package_):
         def rel(is_external, reltype):
@@ -284,6 +265,8 @@ class Describe_ImageParts(object):
 
 
 class Describe_MediaParts(object):
+    """Unit-test suite for `pptx.package._MediaParts` objects."""
+
     def it_can_iterate_the_media_parts_in_the_package(self, iter_fixture):
         media_parts, expected_parts = iter_fixture
         assert list(media_parts) == expected_parts
