@@ -1,8 +1,6 @@
 # encoding: utf-8
 
-"""Test suite for pptx.slide module"""
-
-from __future__ import absolute_import, division, print_function, unicode_literals
+"""Unit-test suite for `pptx.slide` module."""
 
 import pytest
 
@@ -44,6 +42,8 @@ from .unitutil.mock import call, class_mock, instance_mock, method_mock, propert
 
 
 class Describe_BaseSlide(object):
+    """Unit-test suite for `pptx.slide._BaseSlide` objects."""
+
     def it_knows_its_name(self, name_get_fixture):
         base_slide, expected_value = name_get_fixture
         assert base_slide.name == expected_value
@@ -107,6 +107,8 @@ class Describe_BaseSlide(object):
 
 
 class Describe_BaseMaster(object):
+    """Unit-test suite for `pptx.slide._BaseMaster` objects."""
+
     def it_is_a_BaseSlide_subclass(self, subclass_fixture):
         base_master = subclass_fixture
         assert isinstance(base_master, _BaseSlide)
@@ -165,10 +167,21 @@ class Describe_BaseMaster(object):
 
 
 class DescribeNotesSlide(object):
-    def it_can_clone_the_notes_master_placeholders(self, clone_fixture):
-        notes_slide, notes_master_, clone_placeholder_, calls = clone_fixture
+    """Unit-test suite for `pptx.slide.NotesSlide` objects."""
+
+    def it_can_clone_the_notes_master_placeholders(
+        self, request, notes_master_, shapes_
+    ):
+        placeholders = notes_master_.placeholders = (
+            BaseShape(element("p:sp/p:nvSpPr/p:nvPr/p:ph{type=body}"), None),
+            BaseShape(element("p:sp/p:nvSpPr/p:nvPr/p:ph{type=dt}"), None),
+        )
+        property_mock(request, NotesSlide, "shapes", return_value=shapes_)
+        notes_slide = NotesSlide(None, None)
+
         notes_slide.clone_master_placeholders(notes_master_)
-        assert clone_placeholder_.call_args_list == calls
+
+        assert shapes_.clone_placeholder.call_args_list == [call(placeholders[0])]
 
     def it_provides_access_to_its_shapes(self, shapes_fixture):
         notes_slide, NotesSlideShapes_, spTree, shapes_ = shapes_fixture
@@ -177,9 +190,12 @@ class DescribeNotesSlide(object):
         assert shapes is shapes_
 
     def it_provides_access_to_its_placeholders(self, placeholders_fixture):
-        notes_slide, NotesSlidePlaceholders_, spTree, placeholders_ = (
-            placeholders_fixture
-        )
+        (
+            notes_slide,
+            NotesSlidePlaceholders_,
+            spTree,
+            placeholders_,
+        ) = placeholders_fixture
         placeholders = notes_slide.placeholders
         NotesSlidePlaceholders_.assert_called_once_with(spTree, notes_slide)
         assert placeholders is placeholders_
@@ -196,17 +212,6 @@ class DescribeNotesSlide(object):
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture
-    def clone_fixture(self, notes_master_, clone_placeholder_, shapes_prop_, shapes_):
-        notes_slide = NotesSlide(None, None)
-        placeholders = notes_master_.placeholders = (
-            BaseShape(element("p:sp/p:nvSpPr/p:nvPr/p:ph{type=body}"), None),
-            BaseShape(element("p:sp/p:nvSpPr/p:nvPr/p:ph{type=dt}"), None),
-        )
-        calls = [call(placeholders[0])]
-        shapes_.clone_placeholder = clone_placeholder_
-        return notes_slide, notes_master_, clone_placeholder_, calls
-
     @pytest.fixture(
         params=[
             (("SLIDE_IMAGE", "BODY", "SLIDE_NUMBER"), 1),
@@ -258,10 +263,6 @@ class DescribeNotesSlide(object):
 
     # fixture components ---------------------------------------------
 
-    @pytest.fixture
-    def clone_placeholder_(self, request):
-        return method_mock(request, NotesSlideShapes, "clone_placeholder")
-
     @pytest.fixture
     def notes_master_(self, request):
         return instance_mock(request, NotesMaster)
@@ -300,16 +301,14 @@ class DescribeNotesSlide(object):
     def shapes_(self, request):
         return instance_mock(request, NotesSlideShapes)
 
-    @pytest.fixture
-    def shapes_prop_(self, request, shapes_):
-        return property_mock(request, NotesSlide, "shapes", return_value=shapes_)
-
     @pytest.fixture
     def text_frame_(self, request):
         return instance_mock(request, TextFrame)
 
 
 class DescribeSlide(object):
+    """Unit-test suite for `pptx.slide.Slide` objects."""
+
     def it_is_a_BaseSlide_subclass(self, subclass_fixture):
         slide = subclass_fixture
         assert isinstance(slide, _BaseSlide)
@@ -459,6 +458,8 @@ class DescribeSlide(object):
 
 
 class DescribeSlides(object):
+    """Unit-test suite for `pptx.slide.Slides` objects."""
+
     def it_supports_indexed_access(self, getitem_fixture):
         slides, prs_part_, rId, slide_ = getitem_fixture
         slide = slides[0]
@@ -604,6 +605,8 @@ class DescribeSlides(object):
 
 
 class DescribeSlideLayout(object):
+    """Unit-test suite for `pptx.slide.SlideLayout` objects."""
+
     def it_is_a_BaseSlide_subclass(self):
         slide_layout = SlideLayout(None, None)
         assert isinstance(slide_layout, _BaseSlide)
@@ -765,6 +768,8 @@ class DescribeSlideLayout(object):
 
 
 class DescribeSlideLayouts(object):
+    """Unit-test suite for `pptx.slide.SlideLayouts` objects."""
+
     def it_supports_len(self, len_fixture):
         slide_layouts, expected_value = len_fixture
         assert len(slide_layouts) == expected_value
@@ -930,6 +935,8 @@ class DescribeSlideLayouts(object):
 
 
 class DescribeSlideMaster(object):
+    """Unit-test suite for `pptx.slide.SlideMaster` objects."""
+
     def it_is_a_BaseMaster_subclass(self, subclass_fixture):
         slide_master = subclass_fixture
         assert isinstance(slide_master, _BaseMaster)
@@ -967,6 +974,8 @@ class DescribeSlideMaster(object):
 
 
 class DescribeSlideMasters(object):
+    """Unit-test suite for `pptx.slide.SlideMasters` objects."""
+
     def it_knows_how_many_masters_it_contains(self, len_fixture):
         slide_masters, expected_value = len_fixture
         assert len(slide_masters) == expected_value
@@ -1045,44 +1054,29 @@ class DescribeSlideMasters(object):
 
 
 class Describe_Background(object):
-    def it_provides_access_to_its_fill(self, fill_fixture):
-        background, cSld, expected_xml = fill_fixture[:3]
-        from_fill_parent_, fill_ = fill_fixture[3:]
+    """Unit-test suite for `pptx.slide._Background` objects."""
 
-        fill = background.fill
-
-        assert cSld.xml == expected_xml
-        from_fill_parent_.assert_called_once_with(cSld.xpath("p:bg/p:bgPr")[0])
-        assert fill is fill_
-
-    # fixtures -------------------------------------------------------
-
-    @pytest.fixture(
-        params=[
+    @pytest.mark.parametrize(
+        "cSld_xml, expected_cxml",
+        (
             ("p:cSld{a:b=c}", "p:cSld{a:b=c}/p:bg/p:bgPr/(a:noFill,a:effectLst)"),
             (
                 "p:cSld{a:b=c}/p:bg/p:bgRef",
                 "p:cSld{a:b=c}/p:bg/p:bgPr/(a:noFill,a:effectLst)",
             ),
             ("p:cSld/p:bg/p:bgPr/a:solidFill", "p:cSld/p:bg/p:bgPr/a:solidFill"),
-        ]
+        ),
     )
-    def fill_fixture(self, request, from_fill_parent_, fill_):
-        cSld_xml, expected_cxml = request.param
+    def it_provides_access_to_its_fill(self, request, cSld_xml, expected_cxml):
+        fill_ = instance_mock(request, FillFormat)
+        from_fill_parent_ = method_mock(
+            request, FillFormat, "from_fill_parent", autospec=False, return_value=fill_
+        )
         cSld = element(cSld_xml)
         background = _Background(cSld)
 
-        from_fill_parent_.return_value = fill_
+        fill = background.fill
 
-        expected_xml = xml(expected_cxml)
-        return background, cSld, expected_xml, from_fill_parent_, fill_
-
-    # fixture components ---------------------------------------------
-
-    @pytest.fixture
-    def fill_(self, request):
-        return instance_mock(request, FillFormat)
-
-    @pytest.fixture
-    def from_fill_parent_(self, request):
-        return method_mock(request, FillFormat, "from_fill_parent")
+        assert cSld.xml == xml(expected_cxml)
+        from_fill_parent_.assert_called_once_with(cSld.xpath("p:bg/p:bgPr")[0])
+        assert fill is fill_
