@@ -1,8 +1,6 @@
 # encoding: utf-8
 
-"""Unit-test suite for pptx.table module"""
-
-from __future__ import absolute_import, division, print_function, unicode_literals
+"""Unit-test suite for `pptx.table` module."""
 
 import pytest
 
@@ -28,6 +26,8 @@ from .unitutil.mock import call, class_mock, instance_mock, property_mock
 
 
 class DescribeTable(object):
+    """Unit-test suite for `pptx.table.Table` objects."""
+
     def it_provides_access_to_its_cells(self, tbl_, tc_, _Cell_, cell_):
         row_idx, col_idx = 4, 2
         tbl_.tc.return_value = tc_
@@ -40,9 +40,18 @@ class DescribeTable(object):
         _Cell_.assert_called_once_with(tc_, table)
         assert cell is cell_
 
-    def it_provides_access_to_its_columns(self, columns_fixture):
-        table, expected_columns_ = columns_fixture
-        assert table.columns is expected_columns_
+    def it_provides_access_to_its_columns(self, request):
+        columns_ = instance_mock(request, _ColumnCollection)
+        _ColumnCollection_ = class_mock(
+            request, "pptx.table._ColumnCollection", return_value=columns_
+        )
+        tbl = element("a:tbl")
+        table = Table(tbl, None)
+
+        columns = table.columns
+
+        _ColumnCollection_.assert_called_once_with(tbl, table)
+        assert columns is columns_
 
     def it_can_iterate_its_grid_cells(self, request, _Cell_):
         tbl = element("a:tbl/(a:tr/(a:tc,a:tc),a:tr/(a:tc,a:tc))")
@@ -57,9 +66,18 @@ class DescribeTable(object):
         assert cells == expected_cells
         assert _Cell_.call_args_list == [call(tc, table) for tc in expected_tcs]
 
-    def it_provides_access_to_its_rows(self, rows_fixture):
-        table, expected_rows_ = rows_fixture
-        assert table.rows is expected_rows_
+    def it_provides_access_to_its_rows(self, request):
+        rows_ = instance_mock(request, _RowCollection)
+        _RowCollection_ = class_mock(
+            request, "pptx.table._RowCollection", return_value=rows_
+        )
+        tbl = element("a:tbl")
+        table = Table(tbl, None)
+
+        rows = table.rows
+
+        _RowCollection_.assert_called_once_with(tbl, table)
+        assert rows is rows_
 
     def it_updates_graphic_frame_width_on_width_change(self, dx_fixture):
         table, expected_width = dx_fixture
@@ -73,11 +91,6 @@ class DescribeTable(object):
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture
-    def columns_fixture(self, table, columns_):
-        table._columns = columns_
-        return table, columns_
-
     @pytest.fixture
     def dx_fixture(self, graphic_frame_):
         tbl_cxml = "a:tbl/a:tblGrid/(a:gridCol{w=111},a:gridCol{w=222})"
@@ -92,11 +105,6 @@ class DescribeTable(object):
         expected_height = 300
         return table, expected_height
 
-    @pytest.fixture
-    def rows_fixture(self, table, rows_):
-        table._rows = rows_
-        return table, rows_
-
     # fixture components ---------------------------------------------
 
     @pytest.fixture
@@ -107,22 +115,10 @@ class DescribeTable(object):
     def cell_(self, request):
         return instance_mock(request, _Cell)
 
-    @pytest.fixture
-    def columns_(self, request):
-        return instance_mock(request, _ColumnCollection)
-
     @pytest.fixture
     def graphic_frame_(self, request):
         return instance_mock(request, GraphicFrame)
 
-    @pytest.fixture
-    def rows_(self, request):
-        return instance_mock(request, _RowCollection)
-
-    @pytest.fixture
-    def table(self):
-        return Table(element("a:tbl"), None)
-
     @pytest.fixture
     def tbl_(self, request):
         return instance_mock(request, CT_Table)
@@ -688,7 +684,6 @@ class Describe_ColumnCollection(object):
         tbl = element(tbl_cxml)
         columns = _ColumnCollection(tbl, None)
         expected_column_lst = tbl.xpath("//a:gridCol")
-        print(expected_column_lst)
         return columns, expected_column_lst
 
     @pytest.fixture(
