@@ -19,7 +19,6 @@ def test_to_unicode_raises_on_non_string():
 
 
 class DescribeLength(object):
-
     def it_can_construct_from_convenient_units(self, construct_fixture):
         UnitCls, units_val, emu = construct_fixture
         length = UnitCls(units_val)
@@ -34,27 +33,31 @@ class DescribeLength(object):
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture(params=[
-        (Length,      914400,  914400),
-        (Inches,      1.1,    1005840),
-        (Centipoints, 12.5,      1587),
-        (Cm,          2.53,    910799),
-        (Emu,         9144.9,    9144),
-        (Mm,          13.8,    496800),
-        (Pt,          24.5,    311150),
-    ])
+    @pytest.fixture(
+        params=[
+            (Length, 914400, 914400),
+            (Inches, 1.1, 1005840),
+            (Centipoints, 12.5, 1587),
+            (Cm, 2.53, 910799),
+            (Emu, 9144.9, 9144),
+            (Mm, 13.8, 496800),
+            (Pt, 24.5, 311150),
+        ]
+    )
     def construct_fixture(self, request):
         UnitCls, units_val, emu = request.param
         return UnitCls, units_val, emu
 
-    @pytest.fixture(params=[
-        (914400, 'inches', 1.0),
-        (914400, 'centipoints', 7200.0),
-        (914400, 'cm', 2.54),
-        (914400, 'emu', 914400),
-        (914400, 'mm', 25.4),
-        (914400, 'pt', 72.0),
-    ])
+    @pytest.fixture(
+        params=[
+            (914400, "inches", 1.0),
+            (914400, "centipoints", 7200.0),
+            (914400, "cm", 2.54),
+            (914400, "emu", 914400),
+            (914400, "mm", 25.4),
+            (914400, "pt", 72.0),
+        ]
+    )
     def units_fixture(self, request):
         emu, units_prop_name, expected_length_in_units = request.param
         return emu, units_prop_name, expected_length_in_units
